==> mergerfs_2.33.5.orig.tar.gz: mergerfs-2.33.5/src/config_rename_exdev.cpp <==
/*
  ISC License

  Copyright (c) 2021, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "config_rename_exdev.hpp"
#include "ef.hpp"
#include "errno.hpp"

template<>
std::string
RenameEXDEV::to_string(void) const
{
  switch(_data)
    {
    case RenameEXDEV::ENUM::PASSTHROUGH:
      return "passthrough";
    case RenameEXDEV::ENUM::REL_SYMLINK:
      return "rel-symlink";
    case RenameEXDEV::ENUM::ABS_SYMLINK:
      return "abs-symlink";
    }

  return "invalid";
}

template<>
int
RenameEXDEV::from_string(const std::string &s_)
{
  if(s_ == "passthrough")
    _data = RenameEXDEV::ENUM::PASSTHROUGH;
  ef(s_ == "rel-symlink")
    _data = RenameEXDEV::ENUM::REL_SYMLINK;
  ef(s_ == "abs-symlink")
    _data = RenameEXDEV::ENUM::ABS_SYMLINK;
  else
    return -EINVAL;

  return 0;
}

==> mergerfs-2.41.1.tar.gz: mergerfs-2.41.1/src/config_rename_exdev.cpp <==
/*
  ISC License

  Copyright (c) 2021, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "config_rename_exdev.hpp"
#include "ef.hpp"
#include "errno.hpp"

template<>
std::string
RenameEXDEV::to_string(void) const
{
  switch(_data)
    {
    case RenameEXDEV::ENUM::PASSTHROUGH:
      return "passthrough";
    case RenameEXDEV::ENUM::REL_SYMLINK:
      return "rel-symlink";
    case RenameEXDEV::ENUM::ABS_SYMLINK:
      return "abs-symlink";
    }

  return "invalid";
}

template<>
int
RenameEXDEV::from_string(const std::string_view s_)
{
  if(s_ == "passthrough")
    _data = RenameEXDEV::ENUM::PASSTHROUGH;
  ef(s_ == "rel-symlink")
    _data = RenameEXDEV::ENUM::REL_SYMLINK;
  ef(s_ == "abs-symlink")
    _data = RenameEXDEV::ENUM::ABS_SYMLINK;
  else
    return -EINVAL;

  return 0;
}
